@@ -20,8 +20,6 @@
 
 #include <KLazyLocalizedString>
 #include <array>
-#include <ki18n_version.h>
-
 using MessagePtr = KMime::Message::Ptr;
 
 using namespace Akonadi;
@@ -125,3 +123,5 @@ QVariant MessageModel::entityHeaderData(int section, Qt::Orientation orientation
 
     return EntityTreeModel::entityHeaderData(section, orientation, role, headerGroup);
 }
+
+#include "moc_messagemodel.cpp"
